@@ -23,8 +23,8 @@
 #include "../src/fetchjobcalendar.h"
 #include "mailclient_p.h"
 
-#include <kcalcore/event.h>
-#include <kcalcore/icalformat.h>
+#include <kcalendarcore/event.h>
+#include <kcalendarcore/icalformat.h>
 #include <item.h>
 #include <itemcreatejob.h>
 #include <incidencechanger.h>
@@ -37,7 +37,7 @@
 #include <QTest>
 
 using namespace Akonadi;
-using namespace KCalCore;
+using namespace KCalendarCore;
 
 UnitTestBase::UnitTestBase()
 {
@@ -94,8 +94,8 @@ Akonadi::Item::List UnitTestBase::calendarItems()
     FetchJobCalendar::Ptr calendar = FetchJobCalendar::Ptr(new FetchJobCalendar());
     connect(calendar.data(), &FetchJobCalendar::loadFinished, this, &UnitTestBase::onLoadFinished);
     waitForIt();
-    KCalCore::ICalFormat format;
-    QString dump = format.toString(calendar.staticCast<KCalCore::Calendar>());
+    KCalendarCore::ICalFormat format;
+    QString dump = format.toString(calendar.staticCast<KCalendarCore::Calendar>());
     qDebug() << dump;
     calendar->deleteLater();
     return calendar->items();
@@ -107,7 +107,7 @@ void UnitTestBase::onLoadFinished(bool success, const QString &)
     stopWaiting();
 }
 
-void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalendar)
+void UnitTestBase::compareCalendars(const KCalendarCore::Calendar::Ptr &expectedCalendar)
 {
     FetchJobCalendar::Ptr calendar = FetchJobCalendar::Ptr(new FetchJobCalendar());
     connect(calendar.data(), &FetchJobCalendar::loadFinished, this, &UnitTestBase::onLoadFinished);
@@ -119,7 +119,7 @@ void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalen
     const Incidence::List expectedIncidences = expectedCalendar->incidences();
 
     // First, replace the randomly generated UIDs with the UID that came in the invitation e-mail...
-    for(const KCalCore::Incidence::Ptr &incidence : incidences) {
+    for(const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         incidence->setUid(incidence->schedulingID());
         qDebug() << "We have incidece with uid=" << incidence->uid()
                  << "; instanceidentifier=" << incidence->instanceIdentifier();
@@ -131,7 +131,7 @@ void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalen
     }
 
     // ... so we can compare them
-    for(const KCalCore::Incidence::Ptr &incidence : expectedIncidences) {
+    for(const KCalendarCore::Incidence::Ptr &incidence : expectedIncidences) {
         incidence->setUid(incidence->schedulingID());
         qDebug() << "We expect incidece with uid=" << incidence->uid()
                  << "; instanceidentifier=" << incidence->instanceIdentifier();
@@ -144,8 +144,8 @@ void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalen
 
     QCOMPARE(incidences.count(), expectedIncidences.count());
 
-    for (const KCalCore::Incidence::Ptr &expectedIncidence : expectedIncidences) {
-        KCalCore::Incidence::Ptr incidence;
+    for (const KCalendarCore::Incidence::Ptr &expectedIncidence : expectedIncidences) {
+        KCalendarCore::Incidence::Ptr incidence;
         for (int i=0; i<incidences.count(); i++) {
             if (incidences.at(i)->instanceIdentifier() == expectedIncidence->instanceIdentifier()) {
                 incidence = incidences.at(i);
@@ -183,8 +183,8 @@ QByteArray UnitTestBase::readFile(const QString &filename)
 Item UnitTestBase::generateIncidence(const QString &uid, const QString &organizer)
 {
     Item item;
-    item.setMimeType(KCalCore::Event::eventMimeType());
-    KCalCore::Incidence::Ptr incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
+    item.setMimeType(KCalendarCore::Event::eventMimeType());
+    KCalendarCore::Incidence::Ptr incidence = KCalendarCore::Incidence::Ptr(new KCalendarCore::Event());
 
     if (!uid.isEmpty()) {
         incidence->setUid(uid);
@@ -194,7 +194,7 @@ Item UnitTestBase::generateIncidence(const QString &uid, const QString &organize
     incidence->setDtStart(now);
     incidence->setDateTime(now.addSecs(3600), Incidence::RoleEnd);
     incidence->setSummary(QStringLiteral("summary"));
-    item.setPayload<KCalCore::Incidence::Ptr>(incidence);
+    item.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
 
     if (!organizer.isEmpty()) {
         incidence->setOrganizer(organizer);
