@@ -45,7 +45,7 @@ public:
     void handleUidChange(const Akonadi::Item &oldItem, const Akonadi::Item &newItem, const QString &newUid);
 
     // Checks if parent changed and adjust internal hierarchy info
-    void handleParentChanged(const KCalCore::Incidence::Ptr &incidence);
+    void handleParentChanged(const KCalendarCore::Incidence::Ptr &incidence);
 
 public Q_SLOTS:
     void slotDeleteFinished(int changeId,
