@@ -47,9 +47,9 @@ class CalFilterPartStatusProxyModel;
 static bool isStructuralCollection(const Akonadi::Collection &collection)
 {
     const QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar")
-                                                << KCalCore::Event::eventMimeType()
-                                                << KCalCore::Todo::todoMimeType()
-                                                << KCalCore::Journal::journalMimeType();
+                                                << KCalendarCore::Event::eventMimeType()
+                                                << KCalendarCore::Todo::todoMimeType()
+                                                << KCalendarCore::Journal::journalMimeType();
     const QStringList collectionMimeTypes = collection.contentMimeTypes();
     for (const QString &mimeType : mimeTypes) {
         if (collectionMimeTypes.contains(mimeType)) {
@@ -64,7 +64,7 @@ class CheckableProxyModel : public KCheckableProxyModel
 {
     Q_OBJECT
 public:
-    CheckableProxyModel(QObject *parent = nullptr)
+    explicit CheckableProxyModel(QObject *parent = nullptr)
         : KCheckableProxyModel(parent)
     {
     }
@@ -105,7 +105,7 @@ public Q_SLOTS:
             int start = 0,
             int end = -1);
 
-    // KCalCore::CalFilter has changed.
+    // KCalendarCore::CalFilter has changed.
     void onFilterChanged();
 
     void clear();
@@ -131,16 +131,16 @@ public Q_SLOTS:
 
 public:
     Akonadi::CalendarModel::Ptr mETM;
-    Akonadi::EntityMimeTypeFilterModel *mFilteredETM;
+    Akonadi::EntityMimeTypeFilterModel *mFilteredETM = nullptr;
 
     // akonadi id to collections
     QHash<Akonadi::Collection::Id, Akonadi::Collection> mCollectionMap;
-    CheckableProxyModel *mCheckableProxyModel;
-    Akonadi::CollectionFilterProxyModel *mCollectionProxyModel;
-    Akonadi::CalFilterProxyModel *mCalFilterProxyModel; //KCalCore::CalFilter stuff
+    CheckableProxyModel *mCheckableProxyModel = nullptr;
+    Akonadi::CollectionFilterProxyModel *mCollectionProxyModel = nullptr;
+    Akonadi::CalFilterProxyModel *mCalFilterProxyModel = nullptr; //KCalendarCore::CalFilter stuff
     //filter out all invitations and declined events
-    Akonadi::CalFilterPartStatusProxyModel *mCalFilterPartStatusProxyModel;
-    KSelectionProxyModel *mSelectionProxy;
+    Akonadi::CalFilterPartStatusProxyModel *mCalFilterPartStatusProxyModel = nullptr;
+    KSelectionProxyModel *mSelectionProxy = nullptr;
     bool mCollectionFilteringEnabled;
     QSet<Akonadi::Collection::Id> mPopulatedCollectionIds;
     QStringList mMimeTypes;
