@@ -58,7 +58,7 @@ public:
      * This is set when either importIntoExistingFinished() or importIntoNewResource() return false
      * or when the corresponding signals are have success=false.
      */
-    QString errorMessage() const;
+    Q_REQUIRED_RESULT QString errorMessage() const;
 
 Q_SIGNALS:
     /**
