@@ -21,10 +21,14 @@
 #include "publishdialog_p.h"
 
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
 #include <kemailaddress.h>
 #include <kcalendarcore/person.h>
 
+
 #include <KLocalizedString>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <QPointer>
 #include <QTreeView>
 
@@ -82,12 +86,33 @@ void PublishDialog::Private::removeItem()
     mUI.mListWidget->setCurrentRow(row);
 }
 
+void PublishDialog::Private::insertAddresses(const KContacts::Addressee::List &list)
+{
+    for (const KContacts::Addressee &contact : list) {
+        mUI.mNameLineEdit->setEnabled(true);
+        mUI.mEmailLineEdit->setEnabled(true);
+        QListWidgetItem *item = new QListWidgetItem(mUI.mListWidget);
+        item->setSelected(true);
+        mUI.mNameLineEdit->setText(contact.name());
+        mUI.mEmailLineEdit->setText(contact.preferredEmail());
+        mUI.mListWidget->addItem(item);
+    }
+}
+
+
 void PublishDialog::Private::openAddressbook()
 {
-    QPointer<Akonadi::EmailAddressSelectionDialog> dialog(
-        new Akonadi::EmailAddressSelectionDialog(q));
-    dialog->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
+    QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
+    KPluginLoader loader(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+    KPluginFactory *factory = loader.factory();
+    if (factory) {
+        dialog = factory->create<Akonadi::AbstractEmailAddressSelectionDialog>(q);
+    } else {
+        dialog = new Akonadi::EmailAddressSelectionDialog(q);
+    }
 
+    dialog->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
+    connect(dialog.data(), &Akonadi::AbstractEmailAddressSelectionDialog::insertAddresses, this, &PublishDialog::Private::insertAddresses);
     if (dialog->exec() == QDialog::Accepted) {
         const Akonadi::EmailAddressSelection::List selections = dialog->selectedAddresses();
         if (!selections.isEmpty()) {
